\include "deutsch.ly"

#(define-markup-command (raised-digit layout props num) (integer?)
  (let*
      ((mag (magstep (chain-assoc-get 'font-size props 0)))
       (thickness
        (* mag
           (chain-assoc-get 'thickness props 0.16)))
       (dy (* mag 0.25))
       (number-stencil (interpret-markup layout
                                         (prepend-alist-chain 'font-encoding 'fetaNumber props)
                                         (number->string num)))
       (num-x (interval-widen (ly:stencil-extent number-stencil X)
                              (* mag 0.2)))
       (num-y (ly:stencil-extent number-stencil Y)) 
       (is-sane (and (interval-sane? num-x) (interval-sane? num-y)))
       
       (slash-stencil
        (if is-sane
            (ly:make-stencil
             `(draw-line
               ,thickness
               ,(car num-x) ,(+ (+ (interval-center num-y) (* mag 0.4)) dy)
               ,(cdr num-x) ,(- (+ (interval-center num-y) (* mag 0.4)) dy))
             num-x num-y)
            #f)))

    (set! slash-stencil
          (cond
           ((not (ly:stencil? slash-stencil)) #f)
           ((= num 5) (ly:stencil-translate slash-stencil
                                            ;;(cons (* mag -0.05) (* mag 0.42))
                                            (cons (* mag -0.00) (* mag -0.07))

                                            ))
           ((= num 7) (ly:stencil-translate slash-stencil
                                            ;;(cons (* mag -0.05) (* mag 0.42))
                                            (cons (* mag -0.00) (* mag -0.15))

                                            ))
           
           (else slash-stencil)))

    (if slash-stencil
        (set! number-stencil
              (ly:stencil-add number-stencil slash-stencil))
        
        (ly:warning "invalid number for slashed digit ~a" num))


    number-stencil))
    
#(define (my-format-bass-figure figure event context)
  (let* ((fig (ly:event-property event 'figure))
         (fig-markup (if (number? figure)

                         ;; this is not very elegant, but center-aligning all digits
                         ;; is problematic with other markups, and shows problems
                         ;; in the (lack of) overshoot of feta alphabet glyphs.
                         
                         ((if (<= 10 figure)
                              (lambda (y) (make-translate-scaled-markup (cons -0.7 0) y))
                              identity)

                          (if (eq? #t (ly:event-property event 'diminished))
                              (markup #:slashed-digit figure)
                              (markup #:number (number->string figure 10))))
                         #f
                         ))
         (alt (ly:event-property event 'alteration))
         (alt-markup
          (if (number? alt)
              (markup
               #:general-align Y (cond ((= alt FLAT) -0.9)
                                       ((= alt DOUBLE-SHARP) -1)
                                       ((= alt DOUBLE-FLAT) -0.9)
                                       ((= alt NATURAL) -0.5)
                                       (else -0.6))
               #:fontsize
               (if (not (= alt DOUBLE-SHARP))
                   2 4)
               (alteration->text-accidental-markup alt))
              
              #f))
         (plus-markup (if (eq? #t (ly:event-property event 'augmented))
                          (markup #:number "+")
                          #f))

         (alt-dir (ly:context-property context 'figuredBassAlterationDirection))
         (plus-dir (ly:context-property context 'figuredBassPlusDirection))
         )

    (if (and (not fig-markup) alt-markup)
        (begin
          (if (= alt SHARP) 
          (set! fig-markup (markup #:left-align #:pad-x 0.1 alt-markup))
          (set! fig-markup (markup #:left-align #:pad-x 0.3 alt-markup)))
          (set! alt-markup #f)))
          
              
    ;; hmm, how to get figures centered between note, and
    ;; lone accidentals too?
    
    ;;    (if (markup? fig-markup)
    ;;  (set!
    ;;   fig-markup (markup #:translate (cons 1.0 0)
    ;;                      #:hcenter fig-markup)))

    (if alt-markup
        (set! fig-markup
              (markup #:put-adjacent
                      fig-markup X
                      (if (number? alt-dir)
                          alt-dir
                          LEFT)
                      #:pad-x 0.3 alt-markup
                      )))

    
    (if plus-markup
        (set! fig-markup
              (if fig-markup
                  (markup #:put-adjacent
                          fig-markup
                          X (if (number? plus-dir)
                                plus-dir
                                LEFT)
                          #:pad-x 0.2 plus-markup)
                  plus-markup)))
    
    (if (markup? fig-markup)
        (markup #:pad-to-box (cons -0 0) (cons -0 2) #:fontsize -2 fig-markup)
        empty-markup)

    ))



#(define-markup-command (halten layout props laenge) (integer?)
  (interpret-markup layout props (markup #:translate (cons -0.5 0) #:hspace 0 #:raise 1.0 #:bigger (make-string laenge #\_ )))
 )
 
 #(define-markup-command (iname layout props name) (string?)
  (interpret-markup layout props (markup #:combine #:hspace (* (ly:output-def-lookup $defaultpaper 'mm) leftspace) #:large name))
 )
 
#(define leftspace 23)


global = {
  \autoBeamOff
}

boxf = \markup {\center-align { \line { \fontsize #2 "[" \fontsize #0 \musicglyph #"f" \fontsize #2 "]" } } }
boxp = \markup {\center-align { \line { " " \fontsize #2 "[" \fontsize #0 \musicglyph #"p" \fontsize #2 "]" } } } 

#(set-default-paper-size "a4")
#(set-global-staff-size 16)
#(ly:set-option 'point-and-click #f)

\paper {
 print-first-page-number = ##t
 ragged-last-bottom = ##f
 ragged-bottom = ##f
 after-title-space = #0
 before-title-space = 20\mm
 top-margin = 10\mm
 page-top-space = #0
 bottom-margin = 6.7\mm
 left-margin = 18\mm
 foot-separation = 7\mm
 #(define line-width (- paper-width (* 33 mm)))
 oddHeaderMarkup = ##f
 evenHeaderMarkup = ##f
 oddFooterMarkup = \markup \fontsize #1 \fill-line { " " \on-the-fly #print-page-number-check-first \fromproperty #'page:page-number-string }
 evenFooterMarkup = \markup \fontsize #1 \fill-line { \on-the-fly #print-page-number-check-first \fromproperty #'page:page-number-string " " } 
}

myClefSymbol = \markup { \override #'(baseline-skip . 4) \column { \musicglyph #"clefs.G" \fontsize #-3 "(8)" } }

\header {
 tagline = ##f
}
